aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/hw/gpu.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/hw/gpu.h')
-rw-r--r--src/core/hw/gpu.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/core/hw/gpu.h b/src/core/hw/gpu.h
index d07490db..c8f88449 100644
--- a/src/core/hw/gpu.h
+++ b/src/core/hw/gpu.h
@@ -197,7 +197,7 @@ struct Regs {
union {
u32 flags;
- BitField< 0, 1, u32> flip_data; // flips input data horizontally (TODO) if true
+ BitField< 0, 1, u32> flip_vertically; // flips input data vertically
BitField< 1, 1, u32> output_tiled; // Converts from linear to tiled format
BitField< 3, 1, u32> raw_copy; // Copies the data without performing any processing
BitField< 8, 3, PixelFormat> input_format;
@@ -251,6 +251,8 @@ struct Regs {
return content[index];
}
+#undef ASSERT_MEMBER_SIZE
+
private:
/*
* Most physical addresses which GPU registers refer to are 8-byte aligned.